function [A,b] = MKP_poUseckach(x,tau,f,uDirichlet)

%       [A,b] = MKP_poUseckach(x,tau,f)
%       Resi metodou konecnych prvku okrajovou ulohu
%       -(tau(x)*u'(x))' = f(x) v (x(1),x(n))
%               u(x(1)) = u0
%               u(x(n)) = u1
%               + podm. prechodu

n = length(x);
A = sparse(n,n);
b = zeros(n,1);

for k=1:n-1
    ek = [k,k+1];
    xk = x(ek);
    
    tauk = tau(k);
    Ak = alok_derder(xk,tauk);
    
    fk = f(k);
    bk = blok_id(xk,fk);
    
    A(ek,ek) = A(ek,ek) + Ak;
    b(ek) = b(ek) + bk;
end

% nehomogenni Dirichletovy podminky
% u(x(1)) = 0
A(1,2:n) = 0;
% A(2:n,1) = 0; % pak je A symetricka
b(1) = uDirichlet(1) * A(1,1);
% u(x(n)) = 0
A(n,1:n-1) = 0;
% A(1:n-1,n) = 0; % pak je A symetricka
b(n) = uDirichlet(2) * A(n,n);
